@@ -1,5 +1,12 @@
 /*
- *  $Id: sempost.c,v 1.6 2004/04/16 10:01:03 ralf Exp $
+ *  COPYRIGHT (c) 1989-2007.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -34,12 +41,7 @@ int sem_post(
 
   the_semaphore = _POSIX_Semaphore_Get( sem, &location );
   switch ( location ) {
-    case OBJECTS_ERROR:
-      rtems_set_errno_and_return_minus_one( EINVAL );
-    case OBJECTS_REMOTE:
-      _Thread_Dispatch();
-      return POSIX_MP_NOT_IMPLEMENTED();
-      rtems_set_errno_and_return_minus_one( EINVAL );
+
     case OBJECTS_LOCAL:
       _CORE_semaphore_Surrender(
         &the_semaphore->Semaphore,
@@ -52,6 +54,13 @@ int sem_post(
       );
       _Thread_Enable_dispatch();
       return 0;
+
+#if defined(RTEMS_MULTIPROCESSING)
+    case OBJECTS_REMOTE:
+#endif
+    case OBJECTS_ERROR:
+      break;
   }
-  return POSIX_BOTTOM_REACHED();
+
+  rtems_set_errno_and_return_minus_one( EINVAL );
 }
