@@ -1,5 +1,12 @@
 /*
- *  $Id: semunlink.c,v 1.11 2004/11/02 17:21:16 joel Exp $
+ *  COPYRIGHT (c) 1989-2007.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -46,29 +53,12 @@ int sem_unlink(
     rtems_set_errno_and_return_minus_one( status );
   }
 
-  /*
-   *  Don't support unlinking a remote semaphore.
-   */
-
-#if defined(RTEMS_MULTIPROCESSING)
-  if ( !_Objects_Is_local_id((Objects_Id)the_semaphore_id) ) {
-    _Thread_Enable_dispatch();
-    rtems_set_errno_and_return_minus_one( ENOSYS );
-  }
-#endif
-
   the_semaphore = (POSIX_Semaphore_Control *) _Objects_Get_local_object(
     &_POSIX_Semaphore_Information,
     _Objects_Get_index( the_semaphore_id )
   );
 
-#if defined(RTEMS_MULTIPROCESSING)
-  if ( the_semaphore->process_shared == PTHREAD_PROCESS_SHARED ) {
-    _Objects_MP_Close( &_POSIX_Semaphore_Information, the_semaphore_id );
-  }
-#endif
-
-  the_semaphore->linked = FALSE;
+  the_semaphore->linked = false;
   _POSIX_Semaphore_Namespace_remove( the_semaphore );
   _POSIX_Semaphore_Delete( the_semaphore );
 
