@@ -2,14 +2,14 @@
  *  Timer Manager - rtems_timer_cancel directive
  *
  *
- *  COPYRIGHT (c) 1989-2002.
+ *  COPYRIGHT (c) 1989-2007.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: timercancel.c,v 1.6 2005/01/18 09:03:45 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -40,7 +40,7 @@
  */
 
 rtems_status_code rtems_timer_cancel(
-  Objects_Id id
+  rtems_id id
 )
 {
   Timer_Control   *the_timer;
@@ -48,18 +48,19 @@ rtems_status_code rtems_timer_cancel(
 
   the_timer = _Timer_Get( id, &location );
   switch ( location ) {
-    case OBJECTS_REMOTE:            /* should never return this */
-      return RTEMS_INTERNAL_ERROR;
-
-    case OBJECTS_ERROR:
-      return RTEMS_INVALID_ID;
 
     case OBJECTS_LOCAL:
       if ( !_Timer_Is_dormant_class( the_timer->the_class ) )
         (void) _Watchdog_Remove( &the_timer->Ticker );
       _Thread_Enable_dispatch();
       return RTEMS_SUCCESSFUL;
+
+#if defined(RTEMS_MULTIPROCESSING)
+    case OBJECTS_REMOTE:            /* should never return this */
+#endif
+    case OBJECTS_ERROR:
+      break;
   }
 
-  return RTEMS_INTERNAL_ERROR;   /* unreached - only to remove warnings */
+  return RTEMS_INVALID_ID;
 }
